@@ -21,26 +21,18 @@
 
 #include <krun.h>
 
-/*
- * Implementation ExtendedButton
- */
-ExtendedButton::ExtendedButton( QWidget * parent, unsigned short rad)
-	: RoundButton(parent,rad)
-{
-}
-
 /*
  * Implementation CommandoButton
  */
 CommandoButton::CommandoButton(QWidget* parent, unsigned short rad)
-	: ExtendedButton(parent,rad),mType(1)
+    : RoundButton(parent,rad)
 {
 }
 
 Menu* CommandoButton::execute( )
 {
-	KRun::runCommand(command());
-	return NULL;
+    KRun::runCommand(command());
+    return NULL;
 }
 
 /*
@@ -49,17 +41,30 @@ Menu* CommandoButton::execute( )
 
 Menu * SubmenuButton::execute( )
 {
-	return subMenu();
+    return subMenu();
 }
 
 SubmenuButton::SubmenuButton( QWidget * parent,unsigned short rad)
-	:ExtendedButton(parent,rad),mType(2)
+    :RoundButton(parent,rad)
 {
 }
 
 SubmenuButton::SubmenuButton( QWidget * parent, Menu * submenu, unsigned short rad)
-	:ExtendedButton(parent,rad),mSubMenu(submenu),mType(2)
+    :RoundButton(parent,rad),mSubMenu(submenu)
 {
 }
 
+/*void SubmenuButton::setIcon( QString path )
+{
+    mIconPath=path;
+    icon=MainBarIcon(path,radius*2);  //This line sometimes prints: "*** attempt to put segment in horiz list twice"
+    QPixmap overlay = MainBarIcon("kommando_overlay",radius*2);
+    QImage temp1(icon.convertToImage());
+    QImage temp2(overlay.convertToImage());
+    KIconEffect::overlay(temp1,temp2);
+    icon.convertFromImage(temp1);
+    setPixmap(icon);
+    setMask(icon.createHeuristicMask());
+}*/
+
 #include "commandobutton.moc"
