@@ -23,34 +23,22 @@
 #include "roundbutton.h"
 #include "menu.h"
 
-class ExtendedButton : public RoundButton
-{
-	public:
-		ExtendedButton(QWidget* parent,unsigned short rad= 32);
-		virtual Menu* execute()=0;
-
-		virtual int type() const =0;
-};
-
-class CommandoButton : public ExtendedButton
+class CommandoButton : public RoundButton
 {
 	Q_OBJECT
 	public:
 		CommandoButton(QWidget* parent,unsigned short rad= 32);
-		
-		virtual void setCommand(QString com){ mCommando=com; }
-		virtual QString command(){ return mCommando; }
-		
-		virtual Menu* execute();
 
-		virtual int type() const { return mType; }
+		virtual void setCommand(QString com){ mCommando=com; }
+        virtual QString command(){ return mCommando; }
+		virtual Menu* execute();
+        virtual Type type() const { return RoundButton::Commando; }
 
 	protected:
 		QString mCommando;
-		int mType;
 };
 
-class SubmenuButton : public ExtendedButton
+class SubmenuButton : public RoundButton
 {
 	Q_OBJECT
 	public:
@@ -59,14 +47,12 @@ class SubmenuButton : public ExtendedButton
 
 		virtual void setSubMenu(Menu* theValue){ mSubMenu = theValue; }
 		virtual Menu* subMenu() const{ return mSubMenu; }
-		
+
+        //virtual void setIcon(QString path);
 		virtual Menu* execute();
-
-		virtual int type() const { return mType; }
-
+        virtual Type type() const { return RoundButton::Submenu; }
 	protected:
 		Menu* mSubMenu;
-		int mType;
 };
 
 #endif
