@@ -27,47 +27,52 @@
 
 #define BUTTON_DESELECT -1000
 
+class RoundButton;
 
 class Menu : public QButtonGroup
 {
-	Q_OBJECT
-	public:
-		Menu(Menu* parentMenu=NULL);
-		virtual ~Menu();
-		
-		virtual Menu* parentMenu(){ return mParentMenu; }
-		virtual void setParentMenu(Menu* menu){ mParentMenu=menu; }
-		
-		virtual void addChild(Menu* menu);
-		virtual void selectButton(int num);
-		virtual void selectButton(QButton* button);
-		virtual int childCount(){ return children.count(); }
-		virtual void showButtons();
-		virtual void hideButtons();
-		virtual void arrangeButtons();
+    Q_OBJECT
+    public:
+        Menu(Menu* parentMenu=NULL, const QString& appName="");
+        virtual ~Menu();
 
-		virtual Menu* execute();
+        virtual Menu* parentMenu(){ return mParentMenu; }
+        virtual void setParentMenu(Menu* menu){ mParentMenu=menu; }
 
-		virtual int insert ( QButton * button, int id = -1 );
+        virtual void selectButton(int num);
+        virtual void selectButton(QButton* button);
+        virtual void showButtons();
+        virtual void hideButtons();
+        virtual void arrangeButtons();
 
-		void setIconPath(const QString& theValue){ mIconPath = theValue; }
-		QString IconPath() const{ return mIconPath; }
+        virtual Menu* execute();
 
-		int selectedButtonNum() const { return mSelectedButtonNum; }
-		virtual QButton* selectedButton();
+        virtual int insert ( QButton * button, int id = -1 );
+        //use this method for cross linking, otherway there will be problems with deletation
+        virtual int insertNoChild( QButton* button, int id = -1);
 
-	signals:
-		virtual void buttonSelected(int type);
-		
-	protected:
-		Menu* mParentMenu;
-		QString mIconPath;
-		QPtrList<Menu> children;
-		int mSelectedButtonNum;
+        void setIconPath(const QString& theValue){ mIconPath = theValue; }
+        QString IconPath() const{ return mIconPath; }
 
-	protected slots:
-		void slotMouseIn(RoundButton* emitter);
-		void slotMouseOut();
+        int selectedButtonNum() const { return mSelectedButtonNum; }
+        virtual QButton* selectedButton();
+
+        void setAppName(const QString& theValue){ mAppName = theValue; }
+        QString appName() const { return mAppName; }
+
+    signals:
+        virtual void buttonSelected(int type);
+
+    protected:
+        Menu* mParentMenu;
+        QString mIconPath;
+        QPtrList<Menu> children;
+        int mSelectedButtonNum;
+        QString mAppName;
+
+    protected slots:
+        void slotMouseIn(RoundButton* emitter);
+        void slotMouseOut();
 };
 
 #endif
