@@ -27,13 +27,13 @@
 #include "kommando.h"
 
 RoundButton::RoundButton( QWidget* parent, unsigned short rad, const char* name, WFlags f)
-	: QButton(parent, name, f)
+    : QButton(parent, name, f)
 {
-	setRadius(rad);
-	setBackgroundMode(NoBackground);
-	setBackgroundColor(QColor(0,0,0));
+    setRadius(rad);
+    //setBackgroundMode(NoBackground);
+    //setBackgroundColor(QColor(0,0,0));
 
-	background.resize(width(),height());
+    background.resize(width(),height());
 }
 
 RoundButton::~RoundButton()
@@ -42,88 +42,79 @@ RoundButton::~RoundButton()
 
 void RoundButton::drawButton( QPainter *Painter )
 {
-	bitBlt( this, 0, 0, &background );
-
-	drawButtonLabel(Painter);
+    Painter->drawPixmap(0,0,background);
+    drawButtonLabel(Painter);
 }
 
 void RoundButton::drawButtonLabel( QPainter *Painter )
 {
-	/*
-	 * TODO: if the button is a submenu, it should be distinguishable
-	 * from the other ones, maybe add overlays
-	 */
-	
-	//Do we have a pixmap?
-	if(!pixmap()){
-		Painter->drawText(radius,radius,"n/a",5);
-	} else {
-		Painter->drawPixmap(rect(),*pixmap());
-	}
+    //Do we have a pixmap?
+    if(!pixmap()){
+        Painter->drawText(radius,radius,"n/a",5);
+    } else {
+        Painter->drawPixmap(rect(),*pixmap());
+    }
 }
 
 void RoundButton::move( int x, int y )
 {
-	QButton::move(x-radius,y-radius);
+    QButton::move(x-radius,y-radius);
 }
 
 void RoundButton::setRadius( int rad )
 {
-	radius=rad;
-	resize(radius*2,radius*2);
-	setFixedSize(radius*2,radius*2);
-	setIcon(mIconPath);
+    radius=rad;
+    resize(radius*2,radius*2);
+    setFixedSize(radius*2,radius*2);
+    //setIcon(mIconPath);
 }
 
-void RoundButton::setIcon( QString path )
+void RoundButton::setIcon( const QString& path )
 {
-	mIconPath=path;
-	icon=MainBarIcon(path,radius*2);  //This line sometimes prints: "*** attempt to put segment in horiz list twice"
-	setMask(icon.createHeuristicMask());
-	setPixmap(icon);
+    mIconPath=path;
+    icon=MainBarIcon(path,radius*2);
+    setPixmap(icon);
+    setMask(icon.createHeuristicMask());
 }
 
 void RoundButton::show()
 {
-	//get the buttons part of the screenshot
-	copyBlt(&background,0,0,static_cast<Kommando*>(parent())->screenshot(),pos().x(),pos().y(),width(),height());
+    //get the buttons part of the screenshot
+    copyBlt(&background,0,0,static_cast<Kommando*>(parent())->screenshot(),pos().x(),pos().y(),width(),height());
 
-	QButton::show();
+    QButton::show();
 }
 
 bool RoundButton::event( QEvent * evt )
 {
-	switch(evt->type()){
-		case QEvent::Enter:
-			emit mouseIn(this);
-			setActive(true);
-			return true;
-		case QEvent::Leave:
-			emit mouseOut(this);
-			setActive(false);
-			return true;
-		case QEvent::Paint:
-			drawButton(&QPainter(this));
-			return true;
-		default:
-			return QButton::event(evt);
-	}
+    switch(evt->type()){
+        case QEvent::Enter:
+            emit mouseIn(this);
+            setActive(true);
+            return true;
+        case QEvent::Leave:
+            emit mouseOut(this);
+            setActive(false);
+            return true;
+        default:
+            return QButton::event(evt);
+    }
 }
 
 void RoundButton::setActive( bool mode )
 {
-	if(mode){
-		setPixmap(mEffect.apply(icon,KIcon::Desktop,KIcon::ActiveState));
-	} else {
-		setPixmap(mEffect.apply(icon,KIcon::Desktop,KIcon::DefaultState));
-	}
+    if(mode){
+        setPixmap(mEffect.apply(icon,KIcon::Desktop,KIcon::ActiveState));
+    } else {
+        setPixmap(mEffect.apply(icon,KIcon::Desktop,KIcon::DefaultState));
+    }
 }
 
 //key press events need to be ignored, so that they can be captured by the menu
-/* TODO: execution could be placed here! */
+/* TODO execution could be placed here! */
 void RoundButton::keyPressEvent( QKeyEvent * evt )
 {
-	evt->ignore();
+    evt->ignore();
 }
 
 #include "roundbutton.moc"
