@@ -24,20 +24,29 @@
 #include <qpainter.h>
 #include <kiconeffect.h>
 #include <kpixmap.h>
+#include <cassert>
+
+class Menu;
 
 class RoundButton : public QButton  //well, there were round buttons in the begining at least *g*
 {
 	Q_OBJECT
 	public:
-    RoundButton( QWidget* parent=0, unsigned short rad= 32, const char* name= 0, WFlags f = 0);
+        enum Type {Round, Commando, Submenu};
+        RoundButton( QWidget* parent=0, unsigned short rad= 32, const char* name= 0, WFlags f = 0);
 
-    ~RoundButton();
+        ~RoundButton();
 
 		virtual void setRadius(int rad);
-		virtual void setIcon(QString path);
-		virtual void setActive(bool mode);
+		virtual void setIcon(const QString& path);
+        virtual void setActive(bool mode);
 
-	public slots:
+        //This method should not be called on a RoundButton instance. Childclasses have to implement it.
+        virtual Menu* execute(){ assert(0); return 0; }
+        virtual Type type() const { return Round; }
+
+
+    public slots:
 		virtual void move(int x, int y);
 		virtual void show();
 
@@ -54,7 +63,7 @@ class RoundButton : public QButton  //well, there were round buttons in the begi
 		KIconEffect mEffect;
 
 		virtual void keyPressEvent(QKeyEvent* evt);
-		
+
 		virtual void drawButtonLabel(QPainter*);
 		virtual void drawButton(QPainter*);
 		virtual bool event(QEvent* evt);
